==> pyconnectwise-0.4.5.tar.gz: pyconnectwise-0.4.5/src/pyconnectwise/endpoints/manage/SystemMembersIdManageddeviceaccountsEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SystemMembersIdManageddeviceaccountsBulkEndpoint import \
    SystemMembersIdManageddeviceaccountsBulkEndpoint
from pyconnectwise.models.manage import ManagedDeviceAccount
from pyconnectwise.responses.paginated_response import PaginatedResponse


class SystemMembersIdManageddeviceaccountsEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "managedDeviceAccounts", parent_endpoint=parent_endpoint)

        self.bulk = self._register_child_endpoint(
            SystemMembersIdManageddeviceaccountsBulkEndpoint(client, parent_endpoint=self)
        )

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[ManagedDeviceAccount]:
        """
        Performs a GET request against the /system/members/{id}/managedDeviceAccounts endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[ManagedDeviceAccount]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params),
            ManagedDeviceAccount,
            self,
            page,
            page_size,
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[ManagedDeviceAccount]:
        """
        Performs a GET request against the /system/members/{id}/managedDeviceAccounts endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[ManagedDeviceAccount]: The parsed response data.
        """
        return self._parse_many(ManagedDeviceAccount, super()._make_request("GET", data=data, params=params).json())

==> pyconnectwise-0.4.7.tar.gz: pyconnectwise-0.4.7/src/pyconnectwise/endpoints/manage/SystemMembersIdManageddeviceaccountsEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SystemMembersIdManageddeviceaccountsBulkEndpoint import \
    SystemMembersIdManageddeviceaccountsBulkEndpoint
from pyconnectwise.models.manage import ManagedDeviceAccount
from pyconnectwise.responses.paginated_response import PaginatedResponse


class SystemMembersIdManageddeviceaccountsEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "managedDeviceAccounts", parent_endpoint=parent_endpoint)

        self.bulk = self._register_child_endpoint(
            SystemMembersIdManageddeviceaccountsBulkEndpoint(client, parent_endpoint=self)
        )

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[ManagedDeviceAccount]:
        """
        Performs a GET request against the /system/members/{id}/managedDeviceAccounts endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[ManagedDeviceAccount]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params), ManagedDeviceAccount, self, page, page_size, params
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[ManagedDeviceAccount]:
        """
        Performs a GET request against the /system/members/{id}/managedDeviceAccounts endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[ManagedDeviceAccount]: The parsed response data.
        """
        return self._parse_many(ManagedDeviceAccount, super()._make_request("GET", data=data, params=params).json())
